aiml.surrogate\_model package
=============================

Submodules
----------

aiml.surrogate\_model.create\_surrogate\_model module
-----------------------------------------------------

.. automodule:: aiml.surrogate_model.create_surrogate_model
   :members:
   :undoc-members:
   :show-inheritance:

aiml.surrogate\_model.models module
-----------------------------------

.. automodule:: aiml.surrogate_model.models
   :members:
   :undoc-members:
   :show-inheritance:

aiml.surrogate\_model.utils module
----------------------------------

.. automodule:: aiml.surrogate_model.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aiml.surrogate_model
   :members:
   :undoc-members:
   :show-inheritance:
